@@ -411,7 +411,7 @@ sunone_permissions_dialog_finalize (GObject *object)
 }
 
 
-G_DEFINE_TYPE (SunOnePermissionsDialog, sunone_permissions_dialog, GTK_TYPE_DIALOG);
+G_DEFINE_TYPE (SunOnePermissionsDialog, sunone_permissions_dialog, GTK_TYPE_DIALOG)
 
 static void
 merge_acls (SunOnePermissionsDialog *dialog)
